# Lucidium

Experiments in neuro-symbolic reinforcement learning in the pursuit of developing agents/methods to aid in organic reasoning, inference, and logic.

## [Documentation](./documentation/README.md)
* ### [Agents](./agents/README.md)
* ### [Concepts](./documentation/concepts/README.md)
* ### [Environments](./environments/README.md)

## House-Keeping

* ### [Code of Conduct](./CODE_OF_CONDUCT.md)
* ### [Contributing](./CONTRIBUTING)
* ### [License](./LICENSE)